@@ -24,7 +24,11 @@ from enum import Enum
 from typing import Any, Dict, List, Optional
 
 from ..policy import ERROR_TYPE_POLICY
-from ..rule import ERROR_TYPE_RULE, ERROR_TYPE_SCHEDULED_RULE
+from ..rule import (
+    ERROR_TYPE_CORRELATION_RULE,
+    ERROR_TYPE_RULE,
+    ERROR_TYPE_SCHEDULED_RULE,
+)
 
 # Aliases
 ExecutionInputData = Dict[str, Any]
@@ -62,7 +66,12 @@ class ExecutionMatch:
 
     @property
     def errored(self) -> bool:
-        return self.alert_type in (ERROR_TYPE_RULE, ERROR_TYPE_SCHEDULED_RULE, ERROR_TYPE_POLICY)
+        return self.alert_type in (
+            ERROR_TYPE_RULE,
+            ERROR_TYPE_SCHEDULED_RULE,
+            ERROR_TYPE_POLICY,
+            ERROR_TYPE_CORRELATION_RULE,
+        )
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> Optional[ExecutionMatch]:
