@@ -6,6 +6,7 @@ from typing import Any, Callable, Dict, Final, Optional
 
 import jmespath
 
+from panther_core import PantherEvent
 from panther_core.immutable import ImmutableList
 
 SIMPLE_KEY_REGEX: Final = re.compile(r"^[a-zA-Z0-9_]*$")
@@ -79,6 +80,7 @@ class FilterOperator(ABC):  # pylint: disable=too-few-public-methods
 @dataclass
 class FilterCondition(FilterConditionBase):
     value_is_list: Optional[bool] = None
+    value_is_str: Optional[bool] = None
     target_is_ip: Optional[bool] = None
 
     def __post_init__(self) -> None:
@@ -90,6 +92,7 @@ class FilterCondition(FilterConditionBase):
             # use jmespath whenever a more complex expression is detected
             self.compiled_path = jmespath.compile(self.target).search
         self.value_is_list = is_list(self.value)
+        self.value_is_str = isinstance(self.value, str)
         self.target_is_ip = self.target_type_hint == "ip"
 
 
@@ -201,11 +204,29 @@ class LessThanOrEqualFilterOperator(LessThanFilterOperator):
 @op("contains")
 @dataclass
 class ContainsFilterOperator(BaseFilterOperator):
+    """
+    The contains operator exhibits distinct behavior with arrays and strings:
+
+    Arrays:
+        - Prioritizes exact matches, checking if an element is wholly present within the array.
+        - For string arrays specifically, performs partial matches if an exact match is not found.
+
+    Strings:
+        - Always conducts partial matches, assessing whether a string is substring within another string.
+    """
+
     def compare(self, event: Any) -> bool:
         target_value = self.target_value(event)
         if target_value is None:
             return False
-        return self.condition.value in target_value
+        result = self.condition.value in target_value
+        if result:
+            return result
+        if self.condition.value_is_str and isinstance(target_value, list):
+            for string in target_value:
+                if self.condition.value in string:
+                    return True
+        return False
 
 
 @op("!contains")
@@ -489,7 +510,10 @@ class Filter:  # pylint: disable=too-few-public-methods
     def filter(self, event: Any) -> bool:
         if self.exception:
             raise self.exception
-        return self._compiled_filter(event)
+        val = event
+        if isinstance(val, PantherEvent):
+            val = event.to_dict()
+        return self._compiled_filter(val)
 
     def total_conditions(self) -> int:
         total = 0
