@@ -16,6 +16,7 @@ You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+import contextlib
 import json
 import logging
 import os
@@ -34,15 +35,21 @@ from .detection import (
 from .enriched_event import PantherEvent
 from .exceptions import FunctionReturnTypeError, UnknownDestinationError
 from .filter import Filter
+from .util import get_bool_env_var
+
+# We want to default this to false as PAT will want detection output
+DISABLE_OUTPUT = get_bool_env_var("DISABLE_DETECTION_OUTPUT", False)
 
 # Temporary alias for compatibility
 get_logger = logging.getLogger
 
 TYPE_RULE = "RULE"
 TYPE_SCHEDULED_RULE = "SCHEDULED_RULE"
+TYPE_CORRELATION_RULE = "CORRELATION_RULE"
 
 ERROR_TYPE_RULE = "RULE_ERROR"
 ERROR_TYPE_SCHEDULED_RULE = "SCHEDULED_RULE_ERROR"
+ERROR_TYPE_CORRELATION_RULE = "CORRELATION_RULE_ERROR"
 
 _DETECTION_FOLDER = os.path.join(tempfile.gettempdir(), "detections")
 
@@ -68,6 +75,7 @@ DEFAULT_DETECTION_DEDUP_PERIOD_MINS = 60
 
 # Used to check dynamic severity output
 SEVERITY_TYPES = ["INFO", "LOW", "MEDIUM", "HIGH", "CRITICAL"]
+SEVERITY_DEFAULT = "DEFAULT"
 
 ALERT_CONTEXT_FUNCTION = "alert_context"
 DEDUP_FUNCTION = "dedup"
@@ -109,6 +117,7 @@ class Detection(ABC):
                 the events will be deduplicated
         """
         self.logger = get_logger()
+        self.suppress_output = DISABLE_OUTPUT
 
         # Check for required string fields
         for each_field in ["id", "versionId"]:
@@ -197,6 +206,15 @@ class Detection(ABC):
 
         self.skip_filters: bool = bool(config.get("skip_filters"))
 
+        if not ("suppressAlert" in config) or not isinstance(config["suppressAlert"], bool):
+            self.suppress_alert = False
+        else:
+            self.suppress_alert = config["suppressAlert"]
+
+        self.correlation_rule_by_field_name_matches = config.get(
+            "correlationRuleByFieldNameMatches", {}
+        )
+
     @staticmethod
     def _load_detection(identifier: str, config: Mapping) -> ModuleType:
         """Load the detection code as Python module.
@@ -419,7 +437,6 @@ class Detection(ABC):
     def _get_alert_context(
         self, event: Mapping, use_default_on_exception: bool = True
     ) -> Optional[str]:
-
         try:
             command = getattr(self._module, ALERT_CONTEXT_FUNCTION)
             alert_context = self._run_command(command, event, Mapping)
@@ -449,7 +466,6 @@ class Detection(ABC):
         event: Mapping,
         use_default_on_exception: bool = True,
     ) -> str:
-
         try:
             command = getattr(self._module, DEDUP_FUNCTION)
             dedup_string = self._run_command(command, event, str)
@@ -493,7 +509,6 @@ class Detection(ABC):
     def _get_description(
         self, event: Mapping, use_default_on_exception: bool = True
     ) -> Optional[str]:
-
         try:
             command = getattr(self._module, DESCRIPTION_FUNCTION)
             description = self._run_command(command, event, str)
@@ -592,7 +607,6 @@ class Detection(ABC):
     def _get_reference(
         self, event: Mapping, use_default_on_exception: bool = True
     ) -> Optional[str]:
-
         try:
             command = getattr(self._module, REFERENCE_FUNCTION)
             reference = self._run_command(command, event, str)
@@ -621,7 +635,6 @@ class Detection(ABC):
         return reference
 
     def _get_runbook(self, event: Mapping, use_default_on_exception: bool = True) -> Optional[str]:
-
         try:
             command = getattr(self._module, RUNBOOK_FUNCTION)
             runbook = self._run_command(command, event, str)
@@ -650,11 +663,12 @@ class Detection(ABC):
         return runbook
 
     def _get_severity(self, event: Mapping, use_default_on_exception: bool = True) -> Optional[str]:
-
         try:
             command = getattr(self._module, SEVERITY_FUNCTION)
             severity = self._run_command(command, event, str).upper()
             if severity not in SEVERITY_TYPES:
+                if severity == SEVERITY_DEFAULT:
+                    return self.detection_severity
                 self.logger.info(
                     "severity method for detection with id [%s] yielded [%s], expected [%s]",
                     self.detection_id,
@@ -679,7 +693,6 @@ class Detection(ABC):
         return severity
 
     def _get_title(self, event: Mapping, use_default_on_exception: bool) -> Optional[str]:
-
         try:
             command = getattr(self._module, TITLE_FUNCTION)
             title = self._run_command(command, event, str)
@@ -708,7 +721,11 @@ class Detection(ABC):
         return title
 
     def _run_command(self, function: Callable, event: Mapping, expected_type: Any) -> Any:
-        result = function(event)
+        if self.suppress_output:
+            with contextlib.redirect_stdout(None), contextlib.redirect_stderr(None):
+                result = function(event)
+        else:
+            result = function(event)
         # Branch in case of list
         if not isinstance(expected_type, list):
             if not isinstance(result, expected_type):
