@@ -196,9 +196,8 @@ class TestCaseEvaluator:
 
         # first, we should update the detection result, taking into account any
         # ignored exception types passed into this test
-
-        function_results = dict(
-            detectionFunction=FunctionTestResult.new(
+        function_results = {
+            "detectionFunction": FunctionTestResult.new(
                 self._spec.expectations.detection
                 == self._exec_details.primary_functions.detection.output,
                 self._exec_details.primary_functions.detection.output,
@@ -206,7 +205,7 @@ class TestCaseEvaluator:
                     self._exec_details.primary_functions.detection.error, ignore_exception_types
                 ),
             )
-        )
+        }
 
         # We don't include output from other functions
         # unless the test was expected to match and trigger an alert.
@@ -214,67 +213,65 @@ class TestCaseEvaluator:
         # on possible additional failures.
         if self._spec.expectations.detection == self._detection_alert_value:
             function_results.update(
-                dict(
-                    titleFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.title.error is None,
-                        self._exec_details.aux_functions.title.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.title.error, ignore_exception_types
-                        ),
+                titleFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.title.error is None,
+                    self._exec_details.aux_functions.title.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.title.error, ignore_exception_types
                     ),
-                    descriptionFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.description.error is None,
-                        self._exec_details.aux_functions.description.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.description.error,
-                            ignore_exception_types,
-                        ),
+                ),
+                descriptionFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.description.error is None,
+                    self._exec_details.aux_functions.description.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.description.error,
+                        ignore_exception_types,
                     ),
-                    referenceFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.reference.error is None,
-                        self._exec_details.aux_functions.reference.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.reference.error, ignore_exception_types
-                        ),
+                ),
+                referenceFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.reference.error is None,
+                    self._exec_details.aux_functions.reference.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.reference.error, ignore_exception_types
                     ),
-                    severityFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.severity.error is None,
-                        self._exec_details.aux_functions.severity.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.severity.error, ignore_exception_types
-                        ),
+                ),
+                severityFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.severity.error is None,
+                    self._exec_details.aux_functions.severity.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.severity.error, ignore_exception_types
                     ),
-                    runbookFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.runbook.error is None,
-                        self._exec_details.aux_functions.runbook.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.runbook.error, ignore_exception_types
-                        ),
+                ),
+                runbookFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.runbook.error is None,
+                    self._exec_details.aux_functions.runbook.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.runbook.error, ignore_exception_types
                     ),
-                    destinationsFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.destinations.error is None,
-                        self._exec_details.aux_functions.destinations.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.destinations.error,
-                            ignore_exception_types,
-                        ),
+                ),
+                destinationsFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.destinations.error is None,
+                    self._exec_details.aux_functions.destinations.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.destinations.error,
+                        ignore_exception_types,
                     ),
-                    dedupFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.dedup.error is None,
-                        self._exec_details.aux_functions.dedup.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.dedup.error, ignore_exception_types
-                        ),
+                ),
+                dedupFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.dedup.error is None,
+                    self._exec_details.aux_functions.dedup.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.dedup.error, ignore_exception_types
                     ),
-                    alertContextFunction=FunctionTestResult.new(
-                        self._exec_details.aux_functions.alert_context.error is None,
-                        self._exec_details.aux_functions.alert_context.output,
-                        ignoreable_exception(
-                            self._exec_details.aux_functions.alert_context.error,
-                            ignore_exception_types,
-                        ),
+                ),
+                alertContextFunction=FunctionTestResult.new(
+                    self._exec_details.aux_functions.alert_context.error is None,
+                    self._exec_details.aux_functions.alert_context.output,
+                    ignoreable_exception(
+                        self._exec_details.aux_functions.alert_context.error,
+                        ignore_exception_types,
                     ),
-                )
+                ),
             )
 
         generic_error, generic_error_title = self._get_generic_error_details()
